-----------------------------------------------------------------------------------------------
-- Client Lua Script for AmpClassIcons
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
 
-----------------------------------------------------------------------------------------------
-- AmpClassIcons Module Definition
-----------------------------------------------------------------------------------------------
local AmpClassIcons = {} 
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function AmpClassIcons:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here

    return o
end

function AmpClassIcons:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 

-----------------------------------------------------------------------------------------------
-- AmpClassIcons OnLoad
-----------------------------------------------------------------------------------------------
function AmpClassIcons:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("AmpClassIcons.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
	
	-- loads the custom created sprites for the addon
	Apollo.LoadSprites("NewSprite.xml")
	
	--Get the data for the addon Guild Bank
	local gbAddon = Apollo.GetAddon("GuildBank")
	--Override the HelperDrawBankItem with my own function
	gbAddon.HelperDrawBankItem = self.HelperDrawBankItem
	

	
end

-----------------------------------------------------------------------------------------------
-- AmpClassIcons OnDocLoaded
-----------------------------------------------------------------------------------------------
function AmpClassIcons:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "AmpClassIconsForm", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
		
	    self.wndMain:Show(false, true)

		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)
		--Apollo.RegisterEventHandler("GuildBankTab", "OnBankTab", self)

		-- Do additional Addon initialization here
	end
end

-----------------------------------------------------------------------------------------------
-- AmpClassIcons Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here

--Replacement of GuildBank Function
function AmpClassIcons:HelperDrawBankItem(itemDrawing, nTab, nInventorySlot)
	if not self.wndBankItemSlot or not self.wndBankItemSlot[nInventorySlot] then
		return
	end

	
	local wndBankSlot = self.wndBankItemSlot[nInventorySlot]
	wndBankSlot:FindChild("BankItemIcon"):SetData(itemDrawing)
	wndBankSlot:FindChild("BankItemIcon"):SetSprite(itemDrawing:GetIcon())
	self:HelperBuildItemTooltip(wndBankSlot:FindChild("BankItemIcon"), itemDrawing)
	
	--Get the item type
	local itemType = itemDrawing:GetItemTypeName()
	
	--Check if item type is a class AMP and if so replace the icon.
	if itemType == "Warrior AMP" then wndBankSlot:FindChild("BankItemIcon"):SetSprite("NewSprite:AMP_Class_Icon_Warrior")
	elseif itemType == "Spellslinger AMP" then wndBankSlot:FindChild("BankItemIcon"):SetSprite("NewSprite:AMP_Class_Icon_Spellslinger")
	elseif itemType == "Stalker AMP" then wndBankSlot:FindChild("BankItemIcon"):SetSprite("NewSprite:AMP_Class_Icon_Stalker")
	elseif itemType == "Medic AMP" then wndBankSlot:FindChild("BankItemIcon"):SetSprite("NewSprite:AMP_Class_Icon_Medic")
	elseif itemType == "Engineer AMP" then wndBankSlot:FindChild("BankItemIcon"):SetSprite("NewSprite:AMP_Class_Icon_Engineer")
	elseif itemType == "Esper AMP" then wndBankSlot:FindChild("BankItemIcon"):SetSprite("NewSprite:AMP_Class_Icon_Esper")
	else
	end


	local nStackCount = itemDrawing:GetStackCount()
	if nStackCount ~= 1 then
		wndBankSlot:FindChild("BankItemIcon"):SetText(nStackCount)
	end
end



-----------------------------------------------------------------------------------------------
-- AmpClassIconsForm Functions
-----------------------------------------------------------------------------------------------
-- when the OK button is clicked
function AmpClassIcons:OnOK()
	self.wndMain:Close() -- hide the window
end

-- when the Cancel button is clicked
function AmpClassIcons:OnCancel()
	self.wndMain:Close() -- hide the window
end


-----------------------------------------------------------------------------------------------
-- AmpClassIcons Instance
-----------------------------------------------------------------------------------------------
local AmpClassIconsInst = AmpClassIcons:new()
AmpClassIconsInst:Init()
